@@ -1,4 +1,4 @@
-import os, subprocess, wget, requests
+import subprocess, wget, requests
 
 class OpenSUSE:
     """
@@ -7,24 +7,21 @@ class OpenSUSE:
 
 # For installing Basic Packages like Steam, Wine, Gamemode 
     OpenSUSE_Basics = [
-        " zypper install -y steam wine-staging gamemoded libgamemode0 libgamemode0-32bit",
-        " zypper update -y"
-    ]
-
-# For installing Minigalaxy 
-    OpenSUSE_Minigalaxy = " zypper install -y minigalaxy"
+        ["zypper", "install", "-y", "steam", "wine-staging", "gamemoded", "libgamemode0", "libgamemode0-32bit"],
+        ["zypper", "update", "-y"]
+        ]
 
 # For installing Lutris
-    OpenSUSE_Lutris = " zypper install -y lutris"       
+    OpenSUSE_Lutris = ["zypper", "install", "-y", "lutris"]
 
 # For installing The FPS programs and overlays
-    OpenSUSE_Overlays = " zypper install -y goverlay"
+    OpenSUSE_Overlays = ["zypper", "install", "-y", "goverlay"]
 
 # For installing Heroic
     def OpenSUSE_Heroic(self): 
         whoami = str(subprocess.getoutput("whoami"))
         if whoami == "root":
-           print("\n\tPlease run LibreGaming for OpenSUSE Heroic without sudo or doas command, so that it installs correctly\n")
+           print("\nPlease run LibreGaming for OpenSUSE Heroic without sudo or doas command, so that it installs correctly\n")
         else:
             print('Downloading Heroic latest AppImage')
             url = 'https://api.github.com/repos/Heroic-Games-Launcher/HeroicGamesLauncher/releases/latest'
